aboutsummaryrefslogtreecommitdiffstats
path: root/eth/peer.go
diff options
context:
space:
mode:
Diffstat (limited to 'eth/peer.go')
-rw-r--r--eth/peer.go2
1 files changed, 1 insertions, 1 deletions
diff --git a/eth/peer.go b/eth/peer.go
index b5f450855..54c0ea0d5 100644
--- a/eth/peer.go
+++ b/eth/peer.go
@@ -79,7 +79,7 @@ type peer struct {
rw p2p.MsgReadWriter
version int // Protocol version negotiated
- forkDrop *time.Timer // Timed connection dropper if forks aren't validated in time
+ syncDrop *time.Timer // Timed connection dropper if sync progress isn't validated in time
head common.Hash
td *big.Int